@@ -370,8 +370,10 @@ def display_tasks_list(tasks_list):
     """Receives a list of tasks and prints them as a table"""
     tabulated_array = []
     for task in tasks_list:
-        tabulated_array.append([task.id, task.status, task.duration, task.input_file_id])
-    displayable_table = list_to_table(tabulated_array, ["ID", "Status", "Duration (ms)", "Data File ID"])
+        file_name = Path(task.input_file_name).name
+        duration = time.strftime('%H:%M:%S', time.gmtime(task.duration / 1000))
+        tabulated_array.append([file_name, task.id, task.status, duration, task.input_file_id])
+    displayable_table = list_to_table(tabulated_array, ["Name", "ID", "Status", "Duration", "Data File ID"])
     info_message(displayable_table)
 
 
