@@ -4,3 +4,5 @@ Core parts of the SDK: `constants`, `constants`,
 
 from .credentials import Credentials
 from .utils import *
+from .progress_bar import create_progress_bar
+from .config import *
