@@ -72,6 +72,12 @@ class GraphQLRequestException(DiscoException):
         """Returns all messages from the gql errors"""
         return list(map(lambda err: err['message'], self.errors))
 
+    def __str__(self):
+        return ", ".join(self.messages())
+
+    def __repr__(self):
+        return self.errors
+
 
 class BucketPathsException(DiscoException):
     """
