@@ -38,6 +38,14 @@ class Task(BaseModel):
         """
         return self._data.get('request', {}).get('inputFile', {}).get('id')
 
+    @property
+    def input_file_name(self):
+        """
+        Returns:
+            str
+        """
+        return self._data.get('request', {}).get('inputFile', {}).get('name')
+
     @property
     def artifact_ids(self):
         """
