@@ -112,7 +112,8 @@ class TestJobCommands(BaseTest):
             assert result.exit_code == 0
             list_tasks_mock.assert_called()
             is_logged_in_mock.assert_called()
-            assert output_message_includes(result, '| 5e4bef1942abec000cab2a71 | Success  |           17602 | 5e4beee087b4b2000edc6f2e |')
+            assert output_message_includes(result, '| range01.txt | 5e4bef1942abec000cab2a71 | Success  | 00:00:17   '
+                                                   '| 5e4beee087b4b2000edc6f2e |')
 
     @patch('disco.gql.authentication.Authentication.is_logged_in')
     @patch('disco.Job.create')
