@@ -74,7 +74,7 @@ class TestTasksLive(BaseTest):
 
             assert len(current_paths) == 8
 
-            (output_path,) = (path for path in current_paths if path == temp_folder / 'IqoqoTask.stdout.0.txt')
+            (output_path,) = (path for path in current_paths if path == temp_folder / 'DiscoTask.stdout.0.txt')
             current_paths.remove(output_path)
 
             output_path_text = self._stdout_to_output(output_path.read_text())
